==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/loader/impl/StringLoaderSetImpl.java <==
package io.ciera.tool.sql.loader.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.loader.AttributeLoaderSet;
import io.ciera.tool.sql.loader.StringLoader;
import io.ciera.tool.sql.loader.StringLoaderSet;
import io.ciera.tool.sql.loader.impl.AttributeLoaderSetImpl;

import java.util.Arrays;
import java.util.List;


public class StringLoaderSetImpl extends InstanceSet<StringLoaderSet,StringLoader> implements StringLoaderSet {

    // attributes
    @Override
    public void setClass_name( String ref_class_name ) throws XtumlException {
        for ( StringLoader stringloader : this ) stringloader.setClass_name( ref_class_name );
    }
    @Override
    public void setIndex( int ref_index ) throws XtumlException {
        for ( StringLoader stringloader : this ) stringloader.setIndex( ref_index );
    }
    @Override
    public void setAttr_name( String ref_attr_name ) throws XtumlException {
        for ( StringLoader stringloader : this ) stringloader.setAttr_name( ref_attr_name );
    }
    @Override
    public void setLoader_name( String ref_loader_name ) throws XtumlException {
        for ( StringLoader stringloader : this ) stringloader.setLoader_name( ref_loader_name );
    }
    @Override
    public void setLoader_package( String ref_loader_package ) throws XtumlException {
        for ( StringLoader stringloader : this ) stringloader.setLoader_package( ref_loader_package );
    }


    // selections
    @Override
    public AttributeLoaderSet R3008_is_a_AttributeLoader() throws XtumlException {
        AttributeLoaderSet attributeloaderset = new AttributeLoaderSetImpl();
        for ( StringLoader stringloader : this ) attributeloaderset.add( stringloader.R3008_is_a_AttributeLoader() );
        return attributeloaderset;
    }


    @Override
    public StringLoader nullElement() {
        return StringLoaderImpl.EMPTY_STRINGLOADER;
    }

    @Override
    public StringLoaderSet emptySet() {
      return new StringLoaderSetImpl();
    }

    @Override
    public StringLoaderSet value() {
        return this;
    }

    @Override
    public List<StringLoader> elements() {
        return Arrays.asList(toArray(new StringLoader[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/loader/impl/StringLoaderSetImpl.java <==
package io.ciera.tool.sql.loader.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.loader.AttributeLoaderSet;
import io.ciera.tool.sql.loader.StringLoader;
import io.ciera.tool.sql.loader.StringLoaderSet;
import io.ciera.tool.sql.loader.impl.AttributeLoaderSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class StringLoaderSetImpl extends InstanceSet<StringLoaderSet,StringLoader> implements StringLoaderSet {

    public StringLoaderSetImpl() {
    }

    public StringLoaderSetImpl(Comparator<? super StringLoader> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setClass_name( String ref_class_name ) throws XtumlException {
        for ( StringLoader stringloader : this ) stringloader.setClass_name( ref_class_name );
    }
    @Override
    public void setAttr_name( String ref_attr_name ) throws XtumlException {
        for ( StringLoader stringloader : this ) stringloader.setAttr_name( ref_attr_name );
    }
    @Override
    public void setLoader_package( String ref_loader_package ) throws XtumlException {
        for ( StringLoader stringloader : this ) stringloader.setLoader_package( ref_loader_package );
    }
    @Override
    public void setLoader_name( String ref_loader_name ) throws XtumlException {
        for ( StringLoader stringloader : this ) stringloader.setLoader_name( ref_loader_name );
    }
    @Override
    public void setIndex( int ref_index ) throws XtumlException {
        for ( StringLoader stringloader : this ) stringloader.setIndex( ref_index );
    }


    // selections
    @Override
    public AttributeLoaderSet R3008_is_a_AttributeLoader() throws XtumlException {
        AttributeLoaderSet attributeloaderset = new AttributeLoaderSetImpl();
        for ( StringLoader stringloader : this ) attributeloaderset.add( stringloader.R3008_is_a_AttributeLoader() );
        return attributeloaderset;
    }


    @Override
    public StringLoader nullElement() {
        return StringLoaderImpl.EMPTY_STRINGLOADER;
    }

    @Override
    public StringLoaderSet emptySet() {
      return new StringLoaderSetImpl();
    }

    @Override
    public StringLoaderSet emptySet(Comparator<? super StringLoader> comp) {
      return new StringLoaderSetImpl(comp);
    }

    @Override
    public StringLoaderSet value() {
        return this;
    }

    @Override
    public List<StringLoader> elements() {
        return Arrays.asList(toArray(new StringLoader[0]));
    }

}
